==> netbluemind4-4.1.62024.tar.gz: netbluemind4-4.1.62024/netbluemind/addressbook/api/VCardBasicAttribute.py <==
#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VCardBasicAttribute :
    def __init__( self):
        self.parameters = None
        self.value = None
        pass

class __VCardBasicAttributeSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = VCardBasicAttribute()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.addressbook.api.VCardParameter import VCardParameter
        from netbluemind.addressbook.api.VCardParameter import __VCardParameterSerDer__
        parametersValue = value['parameters']
        instance.parameters = serder.ListSerDer(__VCardParameterSerDer__()).parse(parametersValue)
        valueValue = value['value']
        instance.value = serder.STRING.parse(valueValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.addressbook.api.VCardParameter import VCardParameter
        from netbluemind.addressbook.api.VCardParameter import __VCardParameterSerDer__
        parametersValue = value.parameters
        instance["parameters"] = serder.ListSerDer(__VCardParameterSerDer__()).encode(parametersValue)
        valueValue = value.value
        instance["value"] = serder.STRING.encode(valueValue)
        return instance

==> netbluemind5-5.0.7611.tar.gz: netbluemind5-5.0.7611/netbluemind/addressbook/api/VCardBasicAttribute.py <==
#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class VCardBasicAttribute:
    def __init__(self):
        self.parameters = None
        self.value = None
        pass


class __VCardBasicAttributeSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = VCardBasicAttribute()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.addressbook.api.VCardParameter import VCardParameter
        from netbluemind.addressbook.api.VCardParameter import __VCardParameterSerDer__
        parametersValue = value['parameters']
        instance.parameters = serder.ListSerDer(
            __VCardParameterSerDer__()).parse(parametersValue)
        valueValue = value['value']
        instance.value = serder.STRING.parse(valueValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.addressbook.api.VCardParameter import VCardParameter
        from netbluemind.addressbook.api.VCardParameter import __VCardParameterSerDer__
        parametersValue = value.parameters
        instance["parameters"] = serder.ListSerDer(
            __VCardParameterSerDer__()).encode(parametersValue)
        valueValue = value.value
        instance["value"] = serder.STRING.encode(valueValue)
        return instance
